@@ -330,7 +330,7 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
 
 @task
-def build2(javaEnv, dirs, prodSecrets="False",buildApi="True", buildWorker="True"):
+def build2(javaEnv, dirs, prodSecrets="False",shard="",buildApi="True", buildWorker="True"):
 
     # ensure maven installs all build tools
 	local("pwd")
@@ -346,8 +346,8 @@ def build2(javaEnv, dirs, prodSecrets="False",buildApi="True", buildWorker="True
         local('cp api/target/*SNAPSHOT.jar deploy/api/')
 
         if prodSecrets in TRUTH_VALUES:
-            local('aws s3 cp s3://topopps-prod-x/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
-            local('aws s3 cp s3://topopps-prod-x/application-%s.yml deploy/api/config/' % javaEnv)
+            local('aws s3 cp s3://topopps-prod-x/keyset-%s-%s.json deploy/api/config/keyset.json' % (javaEnv, shard))
+            local('aws s3 cp s3://topopps-prod-x/application-%s-%s.yml deploy/api/config/application-%s.yml' % (javaEnv, shard, javaEnv))
         else:
             local('cp config/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
     	    local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
@@ -367,9 +367,9 @@ def build2(javaEnv, dirs, prodSecrets="False",buildApi="True", buildWorker="True
         local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
 
         if prodSecrets in TRUTH_VALUES:
-            local('aws s3 cp s3://topopps-prod-x/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
-    	    local('aws s3 cp s3://topopps-prod-x/application-%s.yml deploy/worker/config/' % javaEnv)
-    	    local('aws s3 cp s3://topopps-prod-x/application-%s-worker.yml deploy/worker/config/' % javaEnv)
+            local('aws s3 cp s3://topopps-prod-x/keyset-%s-%s.json deploy/worker/config/keyset.json' % (javaEnv, shard))
+    	    local('aws s3 cp s3://topopps-prod-x/application-%s-%s.yml deploy/worker/config/application-%s.yml' % (javaEnv, shard, javaEnv))
+    	    local('aws s3 cp s3://topopps-prod-x/application-%s-%s-worker.yml deploy/worker/config/application-%s-worker.yml' % (javaEnv, shard, javaEnv))
         else:
             local('cp config/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
             local('cp config/application-%s.yml deploy/worker/config/' % javaEnv)
